NAME

App::sdif - sdif and family tools, cdif and watchdiff

SYNOPSIS

sdif f1 f2

diff -c f1 f2 | cdif

git diff | sdif -n

watchdiff df

DESCRIPTION

sdif-tools is composed of sdif and related tools including cdif and watchdiff.

sdif prints diff output in side-by-side format.

cdif adds visual effects to diff output, comparing lines word by word or character by character.

watchdiff calls a command repeatedly, and prints its output with visual effects to emphasize the modified part.

See the manual of each command for details.

INSTALL

$ cpanm App::sdif

GIT

These are sample configurations for using the sdif family under git. The mecab command has to be installed to use the --mecab option.

~/.gitconfig
    [pager]
        log  = sdif | less
        show = sdif | less
        diff = sdif | less

~/.sdifrc
    option default -n --margin=4

~/.cdifrc
    option default --mecab

~/.profile
    export LESS="-cR"
    export LESSANSIENDCHARS="mK"

Everything can be written in ~/.gitconfig instead:

[pager]
    log  = sdif -n --margin=4 --mecab | env LESSANSIENDCHARS=mK less -cR
    show = sdif -n --margin=4 --mecab | env LESSANSIENDCHARS=mK less -cR
    diff = sdif -n --margin=4 --mecab | env LESSANSIENDCHARS=mK less -cR

SEE ALSO

sdif, cdif, watchdiff

Getopt::EX

AUTHOR

Kazumasa Utashiro

LICENSE

Copyright 1992- Kazumasa Utashiro.

These commands and libraries are free software; you can redistribute it and/or modify it under the same terms as Perl itself.